@@ -254,6 +254,7 @@ This variable has to be set before `no-littering' is loaded.")
     (setq ac-comphist-file                 (var "ac-comphist.el"))
     (setq amx-save-file                    (var "amx-save.el"))
     (setq anaconda-mode-installation-directory (var "anaconda-mode/"))
+    (setq annotate-file                    (var "annotations.el"))
     (setq async-byte-compile-log-file      (var "async-bytecomp.log"))
     (eval-after-load 'bbdb
       `(make-directory ,(var "bbdb/") t))
@@ -264,13 +265,20 @@ This variable has to be set before `no-littering' is loaded.")
       `(make-directory ,(var "bmkp/") t))
     (setq bmkp-current-bookmark-file       (var "bmkp/current-bookmark.el"))
     (setq bmkp-last-bookmark-file          (var "bmkp/last-bookmark.el"))
-    (eval-after-load 'company-statistics
+    (setq bookiez-file                     (var "bookiez"))
+    (eval-after-load 'company
       `(make-directory ,(var "company/") t))
+    (setq cider-repl-history-file          (var "cider-repl-history.el"))
     (setq company-statistics-file          (var "company/statistics.el"))
-    (setq dap--breakpoints-file            (var "dap-breakpoints"))
+    (setq company-tabnine-binaries-folder  (var "company/tabnine-binaries"))
+    (setq dap-breakpoints-file             (var "dap/breakpoints.el"))
     (setq dap-java-test-runner             (var "lsp-java/eclipse.jdt.ls/test-runner/junit-platform-console-standalone.jar"))
+    (setq dap-utils-extension-path         (var "dap/extensions/"))
+    (setq debbugs-gnu-persistency-file     (var "debbugs.el"))
     (setq dired-recent-directories-file    (var "dired-recent-directories.el"))
     (setq elbank-data-file                 (var "elbank-data.el"))
+    (setq elmo-msgdb-directory             (var "elmo/"))
+    (setq elmo-split-log-file              (var "elmo/split-log"))
     (eval-after-load 'elfeed
       `(make-directory ,(var "elfeed/") t))
     (setq elfeed-db-directory              (var "elfeed/db/"))
@@ -314,10 +322,12 @@ directories."
     (setq keyfreq-file-lock                (var "keyfreq.lock"))
     (eval-after-load 'lookup
       `(make-directory ,(etc "lookup/") t))
+    (setq libbcel-oauth-store-filename     (var "libbcel-oauth-store.el.gpg"))
     (setq litable-list-file                (var "litable-list.el"))
     (setq logview-cache-filename           (var "logview-cache"))
     (setq logview-views-file               (etc "logview-views"))
     (setq lookup-init-directory            (etc "lookup/"))
+    (setq lsp-python-ms-dir                (var "lsp-python-ms/"))
     (setq lsp-session-file                 (var "lsp-session.el"))
     (setq lsp-java-workspace-dir           (var "lsp-java/workspace/"))
     (setq lsp-java-server-install-dir      (var "lsp-java/eclipse.jdt.ls/server/"))
@@ -336,14 +346,18 @@ directories."
       `(make-directory ,(var "org/caldav/save") t))
     (setq org-caldav-backup-file           (var "org/caldav/backup.org"))
     (setq org-caldav-save-directory        (var "org/caldav/save"))
+    (setq org-journal-cache-file           (var "org/journal-cache.el"))
+    (setq org-recent-headings-save-file    (var "org/recent-headings.el"))
     (setq pandoc-data-dir                  (etc "pandoc-mode/"))
     (setq pcache-directory                 (var "pcache/"))
     (setq persistent-scratch-save-file     (var "persistent-scratch.el"))
     (setq persp-save-dir                   (var "persp-mode/"))
     (eval-after-load 'projectile
       `(make-directory ,(var "projectile/") t))
+    (setq prescient-save-file              (var "prescient-save.el"))
     (setq projectile-cache-file            (var "projectile/cache.el"))
     (setq projectile-known-projects-file   (var "projectile/known-projects.el"))
+    (setq psession-elisp-objects-default-directory (var "psession/"))
     (setq purpose-default-layout-file      (etc "window-purpose/default-layout.el"))
     (setq purpose-layout-dirs              (list (etc "window-purpose/layouts/")))
     (setq pyim-dcache-directory            (var "pyim/dcache/"))
@@ -362,10 +376,20 @@ directories."
     (setq transient-history-file           (var "transient/history.el"))
     (setq transient-levels-file            (etc "transient/levels.el"))
     (setq transient-values-file            (etc "transient/values.el"))
-    (setq treemacs-persist-file            (var "treemacs-persist.org"))
+    (setq treemacs-persist-file            (var "treemacs/persist.org"))
+    (setq treemacs-last-error-persist-file (var "treemacs/persist-last-error.org"))
     (setq undo-tree-history-directory-alist (list (cons "." (var "undo-tree-hist/"))))
     (setq user-emacs-ensime-directory      (var "ensime/"))
     (setq vimish-fold-dir                  (var "vimish-fold/"))
+    (eval-after-load 'wl
+      `(make-directory ,(etc "wanderlust") t))
+    (setq wl-init-file                     (etc "wanderlust/init.el"))
+    (setq wl-folders-file                  (etc "wanderlust/folders"))
+    (setq wl-address-file                  (etc "wanderlust/address"))
+    (setq wl-alias-file                    (etc "wanderlust/alias"))
+    (setq wl-x-face-file                   (etc "wanderlust/x-face"))
+    (setq wl-temporary-file-directory      (var "wanderlust-tmp"))
+    (setq x86-lookup-cache-directory       (var "x86-lookup/cache/"))
     (eval-after-load 'xkcd
       `(make-directory ,(var "xkcd/") t))
     (setq xkcd-cache-dir                   (var "xkcd/"))
